@@ -110,6 +110,20 @@ impl<T: StorableType> Entry<T> {
         }
     }
 
+    #[async_recursion]
+    pub async fn dereference(mut self) -> Result<Entry<T>, CryptoError> {
+        match self.value {
+            State::Referenced {
+                ref path,
+                ref storer,
+            } => {
+                let entry = storer.get::<T>(path).await?;
+                Ok(entry.dereference().await?)
+            }
+            _ => Ok(self)
+        }
+    }
+
     #[async_recursion]
     pub async fn take_resolve(mut self) -> Result<T, CryptoError> {
         match self.resolved_value.take() {
