@@ -37,6 +37,9 @@ pub enum CryptoError {
 
     /// Wrong nonce was provided during seal/unseal operation
     WrongNonceType,
+
+    /// The method is not implemented for the storage implementation
+    NotImplemented
 }
 
 impl Error for CryptoError {
@@ -50,6 +53,7 @@ impl Error for CryptoError {
             CryptoError::NotDowncastable => None,
             CryptoError::NotDeserializableToBaseDataType => None,
             CryptoError::WrongNonceType => None,
+            CryptoError::NotImplemented => None,
         }
     }
 }
@@ -98,6 +102,9 @@ impl Display for CryptoError {
             CryptoError::WrongNonceType => {
                 write!(f, "Invalid type of nonce was provided for the operation")
             }
+            CryptoError::NotImplemented => {
+                write!(f, "The method is not implemented for the storage implementation")
+            }
         }
     }
 }
