@@ -34,8 +34,11 @@ use sodiumoxide::crypto::{
         SecretKey as ExternalSodiumOxideEd25519SecretAsymmetricKey,
     },
 };
+use spki::AlgorithmIdentifier;
 use std::{boxed::Box, convert::TryFrom};
 
+use super::HasAlgorithmIdentifier;
+
 // SYMMETRIC KEY \\
 #[derive(Serialize, Deserialize, Debug)]
 pub struct SodiumOxideSymmetricKeyAlgorithm {
@@ -648,6 +651,15 @@ impl HasByteSource for SodiumOxideCurve25519PublicAsymmetricKey {
     }
 }
 
+impl HasAlgorithmIdentifier for SodiumOxideCurve25519PublicAsymmetricKey {
+    fn algorithm_identifier<'a>(&self) -> AlgorithmIdentifier<'a> {
+        AlgorithmIdentifier {
+            oid: spki::ObjectIdentifier::new("1.3.101.110"),
+            parameters: None,
+        }
+    }
+}
+
 impl SodiumOxideCurve25519PublicAsymmetricKey {
     pub const KEYBYTES: usize = EXTERNALSODIUMOXIDEPUBLICASYMMETRICKEYBYTES;
 
@@ -670,6 +682,15 @@ impl HasPublicKey for SodiumOxideCurve25519SecretAsymmetricKey {
     }
 }
 
+impl HasAlgorithmIdentifier for SodiumOxideCurve25519SecretAsymmetricKey {
+    fn algorithm_identifier<'a>(&self) -> AlgorithmIdentifier<'a> {
+        AlgorithmIdentifier {
+            oid: spki::ObjectIdentifier::new("1.3.101.110"),
+            parameters: None,
+        }
+    }
+}
+
 // SECRET SIGNING KEY \\
 #[derive(Serialize, Deserialize, Debug, Clone, Copy)]
 pub struct SodiumOxideEd25519SecretAsymmetricKeyBuilder {}
@@ -724,7 +745,10 @@ impl StorableType for SodiumOxideEd25519SecretAsymmetricKey {}
 
 impl Signer for SodiumOxideEd25519SecretAsymmetricKey {
     fn sign(&self, bytes: ByteSource) -> Result<ByteSource, CryptoError> {
-        Ok(sign::sign(bytes.get()?, &self.secret_key).as_slice().into())
+        Ok(sign::sign_detached(bytes.get()?, &self.secret_key)
+            .to_bytes()
+            .as_ref()
+            .into())
     }
 }
 
@@ -869,6 +893,15 @@ impl HasByteSource for SodiumOxideEd25519PublicAsymmetricKey {
     }
 }
 
+impl HasAlgorithmIdentifier for SodiumOxideEd25519PublicAsymmetricKey {
+    fn algorithm_identifier<'a>(&self) -> AlgorithmIdentifier<'a> {
+        AlgorithmIdentifier {
+            oid: spki::ObjectIdentifier::new("1.3.101.112"),
+            parameters: None,
+        }
+    }
+}
+
 impl SodiumOxideEd25519PublicAsymmetricKey {
     pub const KEYBYTES: usize = EXTERNALSODIUMOXIDEPUBLICASYMMETRICKEYBYTES;
 
@@ -891,6 +924,15 @@ impl HasPublicKey for SodiumOxideEd25519SecretAsymmetricKey {
     }
 }
 
+impl HasAlgorithmIdentifier for SodiumOxideEd25519SecretAsymmetricKey {
+    fn algorithm_identifier<'a>(&self) -> AlgorithmIdentifier<'a> {
+        AlgorithmIdentifier {
+            oid: spki::ObjectIdentifier::new("1.3.101.112"),
+            parameters: None,
+        }
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use super::{
